// SPDX-License-Identifier: LGPL-2.1-or-later
//
// SPDX-FileCopyrightText: 2009 Bastian Holst <bastianholst@gmx.de>
//

// Own
#include "StoragePolicy.h"

using namespace Marble;

StoragePolicy::StoragePolicy( QObject *parent )
    : QObject( parent )
{}

#include "moc_StoragePolicy.cpp"
